use strict;
use warnings;
use Test::More;

# generated by Dist::Zilla::Plugin::Test::PodSpelling 2.007005
use Test::Spelling 0.12;
use Pod::Wordlist;


add_stopwords(<DATA>);
all_pod_files_spelling_ok( qw( bin lib ) );
__DATA__
Bandung
Dave
David
Dist
Etheridge
Golden
Haryanto
Ioan
Karen
OSPrereqs
PC
Plugin
Rogers
Rolsky
Steven
Zilla
autarch
dagolden
ether
ini
ioanr
lib
on
pc
perlancar
stevenharyanto
